@@ -26,7 +26,7 @@
 
 #define FST_MAJOR_VERSION 0
 #define FST_MINOR_VERSION 115
-#define FST_MICRO_VERSION 0
+#define FST_MICRO_VERSION 2
 
 #define FST_VERSIONNUM(X, Y, Z)                                         \
         ((X)*10000 + (Y)*1000 + (Z))
@@ -42,7 +42,9 @@
 #if defined(__GNUC__) || defined(__clang__)
 # define FST_DEPRECATE_UNKNOWN(x) x __attribute__ ((deprecated))
 #elif defined(_MSC_VER)
-# define FST_DEPRECATE __declspec(deprecated)
+# define FST_DEPRECATE_UNKNOWN(x) __declspec(deprecated) x
+/* on second thought, MSVC doesn't allow to deprecate enum values, so blow it: */
+# define FST_DONT_DEPRECATE_UNKNOWN
 #else
 # define FST_DEPRECATE_UNKNOWN(x) x
 #endif
@@ -52,14 +54,16 @@
 # define FST_DEPRECATE_UNKNOWN(x) x
 #endif
 
+#define FST_DEPRECATE_ENUM(x) FST_DEPRECATE_UNKNOWN(x)
+
 #define FST_UNKNOWN(x) x
 #define FST_ENUM(x, y) x = y
 #if 0
-# define FST_ENUM_EXPERIMENTAL(x, y) FST_DEPRECATE_UNKNOWN(x) = y
+# define FST_ENUM_EXPERIMENTAL(x, y) FST_DEPRECATE_ENUM(x) = y
 #else
 # define FST_ENUM_EXPERIMENTAL(x, y) x = y
 #endif
-#define FST_ENUM_UNKNOWN(x) FST_DEPRECATE_UNKNOWN(x) = 100000 + __LINE__
+#define FST_ENUM_UNKNOWN(x) FST_DEPRECATE_ENUM(x) = (100000 + __LINE__)
 
 /* name mangling */
 
@@ -239,7 +243,9 @@ typedef enum {
 
   FST_EFFECT_OPCODE_UNKNOWN(Idle),
 
-#warning document origin of eff*SetProgram
+#if defined(__GNUC__) || defined(__clang__)
+# warning document origin of eff*SetProgram
+#endif
   FST_EFFECT_OPCODE_UNKNOWN(BeginSetProgram),
   FST_EFFECT_OPCODE_UNKNOWN(EndSetProgram),
 
@@ -325,7 +331,9 @@ typedef enum {
   FST_SPEAKER_UNKNOWN(Trr),
   FST_SPEAKER_UNKNOWN(Lfe2),
 
-#warning origin of kSpeakerM
+#if defined(__GNUC__) || defined(__clang__)
+# warning document origin of kSpeakerM
+#endif
   FST_SPEAKER_UNKNOWN(Undefined),
   fst_speakerLast /* last enum */
 } t_fstSpeakerArrangementType;
@@ -357,10 +365,7 @@ enum {
 
   /* returned by audioMasterGetAutomationState: */
   FST_FLAG_UNKNOWN(AutomationUnsupported),
-  /* returned by audioMasterGetCurrentProcessLevel: */
-  FST_CONSTANT_UNKNOWN(ProcessLevelUnknown),
-  /* returned by audioMasterGetLanguage: */
-  FST_CONSTANT_UNKNOWN(LangEnglish),
+
 
   /* used as t_fstPinProperties.flags */
   FST_FLAG_UNKNOWN(PinIsActive),
@@ -392,6 +397,22 @@ typedef enum {
   FST_CONSTANT(SysExType, 6)
 } t_fstEventType;
 
+enum {
+  /* returned by audioMasterGetCurrentProcessLevel: */
+      FST_CONSTANT_EXPERIMENTAL(ProcessLevelUnknown, 0),
+      FST_CONSTANT(ProcessLevelRealtime, 2),
+      FST_CONSTANT(ProcessLevelOffline, 4),
+#if defined(__GNUC__) || defined(__clang__)
+# warning document origin of ProcesslevelUser
+#endif
+      FST_CONSTANT_UNKNOWN(ProcessLevelUser), /* vstplugin~ */
+};
+
+enum {
+      /* returned by audioMasterGetLanguage: */
+      FST_CONSTANT_UNKNOWN(LangEnglish),
+};
+
 
 /* deltaFrames: used by JUCE as "timestamp" (to sort events) */
 #define FSTEVENT_COMMON \
@@ -469,7 +490,9 @@ typedef struct fstTimeInfo_ {
 
   int FST_UNKNOWN(currentBar), FST_UNKNOWN(magic); /* we just made these fields up, as their values seem to be neither flags nor smtp* */
 
-#warning document origin samplesToNextClock
+#if defined(__GNUC__) || defined(__clang__)
+# warning document origin of samplesToNextClock
+#endif
   /* this used to be '_pad' */
   FST_UNKNOWN(int) samplesToNextClock;/* ? */
 
@@ -553,7 +576,9 @@ typedef t_fstPtrInt VstIntPtr;
 typedef t_fstInt32 VstInt32;
 
 const int FST_CONST(EffectMagic, 0x56737450);
-#warning document origin of CCONST
+#if defined(__GNUC__) || defined(__clang__)
+# warning document origin of CCONST
+#endif
 #define CCONST(a,b,c,d) ((((unsigned char)a)<<24) + (((unsigned char)b)<<16) + (((unsigned char)c)<<8) + ((unsigned char)d))
 
 #endif /* FST_fst_h_ */
